@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::Shootout::binarytrees;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::Shootout::binarytrees::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 # COMMAND LINE:
 # /usr/bin/perl binarytrees.perl-2.perl 20
@@ -107,7 +110,15 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::Shootout::binarytrees
 
 =head1 NAME
 
@@ -117,3 +128,20 @@ Benchmark::Perl::Formance::Plugin::Shootout::binarytrees - Language shootout plu
 
 This plugin does some runs the "binarytrees" benchmark from the
 Language Shootout.
+
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
